﻿using System;
using System.Globalization;
using System.Text.RegularExpressions;
using System.Threading;

namespace TestProject
{
    /// <summary>
    /// 문자열 확장
    /// </summary>
    public static class StringExtension
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Static
        //////////////////////////////////////////////////////////////////////////////// Public

        #region 파스칼 표기법 문자열 구하기 - ToPascalCase(source)

        /// <summary>
        /// 파스칼 표기법 문자열 구하기
        /// </summary>
        /// <param name="source">소스 문자열</param>
        /// <returns>파스칼 표기법 문자열</returns>
        public static string ToPascalCase(this string source)
        {
            TextInfo textInfo = Thread.CurrentThread.CurrentCulture.TextInfo;

            source = textInfo.ToTitleCase(source);

            string[] partArray = source.Split(new char[] {}, StringSplitOptions.RemoveEmptyEntries);

            string result = string.Join(string.Empty, partArray);

            return result;
        }

        #endregion
        #region 카멜 표기법 문자열 구하기 - ToCamelCase(source)

        /// <summary>
        /// 카멜 표기법 문자열 구하기
        /// </summary>
        /// <param name="source">소스 문자열</param>
        /// <returns>카멜 표기법 문자열</returns>
        public static string ToCamelCase(this string source)
        {
            source = source.ToPascalCase();

            return source.Substring(0, 1).ToLower() + source.Substring(1);
        }

        #endregion
        #region 고유 표기법 문자열 구하기 - ToProperCase(source)

        /// <summary>
        /// 고유 표기법 문자열 구하기
        /// </summary>
        /// <param name="source">소스 문자열</param>
        /// <returns>고유 표기법 문자열</returns>
        public static string ToProperCase(this string source)
        {
            const string pattern = @"(?<=\w)(?=[A-Z])";

            string result = Regex.Replace(source, pattern, " ", RegexOptions.None);

            return result.Substring(0, 1).ToUpper() + result.Substring(1);
        }

        #endregion
    }
}